``pyramid_ldap3``
=================

``pyramid_ldap3`` provides LDAP authentication services for your Pyramid
application.  It is a fork of the ``pyramid_ldap`` package with the goal
of eliminating the dependency on ``python-ldap`` and ``ldappool``,
replacing it with a dependency on ``python3-ldap``, which is a pure
Python package that also supports Python 3.

See the documentation at
http://pyramid-ldap3.readthedocs.org/en/latest/
for more information.

